@@ -39,6 +39,7 @@ function Webweb(wwdata) {
         'invertBinarySizes' : false,
         'colorBy' : 'none',
         'sizeBy' : 'none',
+        'showLegend': true,
         'scaleLinkOpacity' : false,
         'networkName' : this.networkNames[0],
         'networkLayer' : 0,
@@ -107,6 +108,15 @@ Webweb.prototype.standardizeNetwork = function(network) {
     for (var i in network.layers) {
         network.layers[i] = this.standardizeLayer(network.layers[i]);
         network.layers[i].nodeIdMap = this.getNodeIdMap(network.layers[i]);
+
+        for (var j in network.layers[i].edgeList) {
+            var edge = network.layers[i].edgeList[j];
+            var source = edge[0];
+            var target = edge[1];
+
+            network.layers[i].edgeList[j][0] = isNaN(source) ? source : +source;
+            network.layers[i].edgeList[j][1] = isNaN(target) ? target : +target;
+        }
     }
 
     return network;
@@ -134,14 +144,16 @@ Webweb.prototype.getNodeIdMap = function(network) {
     }
 
     if (allInts(nodeNames)) {
-        nodeNames.sort();
+        nodeNames.sort(function(a, b){return a-b});
     }
 
+
     var unusedId = 0;
     var nodeIdMap = {};
     nodeNames.forEach(function(name) {
         if (nodeIdMap[name] == undefined) {
             nodeIdMap[name] = unusedId;
+            nodeIdMap[+name] = unusedId;
             unusedId += 1;
         }
     });
@@ -154,6 +166,11 @@ Webweb.prototype.getNodeIdMap = function(network) {
         }
     }
 
+    var count = 0;
+    for (var i in nodeIdMap) {
+        count += 1;
+    }
+
     var displayMetadataValuesCount = metadataValuesCount(this.display.metadata);
 
     if (displayMetadataValuesCount > unusedId) {
@@ -176,6 +193,20 @@ Webweb.prototype.getNodeIdMap = function(network) {
 
     return nodeIdMap;
 }
+Webweb.prototype.getNodeCount = function(network) {
+    var nodeIdMap = this.getNodeIdMap(network);
+
+    var count = 0;
+    for (var node in nodeIdMap) {
+        var nodeId = nodeIdMap[node];
+        if (nodeId > count) {
+            count = nodeId
+        }
+    }
+    // those were indexes; add one
+    count += 1;
+    return count;
+}
 Webweb.prototype.standardizeLayer = function(layer) {
     if (this.display.metadata == undefined) {
         this.display.metadata = {};
@@ -216,7 +247,7 @@ Webweb.prototype.createNodes = function() {
     for (var i in this.networks) {
         var network = this.networks[i];
         for (var i in network.layers) {
-            var nodeCount = getObjetPropertyCount(network.layers[i].nodeIdMap);
+            var nodeCount = this.getNodeCount(network.layers[i]);
 
             if (nodeCount > this.maxNodeCount) {
                 this.maxNodeCount = nodeCount;
@@ -299,7 +330,7 @@ Node.prototype.pushNodeText = function() {
     var radius = this.radius();
     if (! this.nonInteractive) {
         if (this.matchesString() || webweb.display.showNodeNames || this.containsMouse(radius)) {
-            if (webweb.simulation.alpha() < .01) {
+            if (webweb.simulation.alpha() < .05 || webweb.display.freezeNodeMovement) {
                 var text = this.name || this.idx;
                 var textX = this.x + 1.1 * radius;
                 var textY = this.y - 1.1 * radius;
@@ -419,7 +450,7 @@ Link.prototype.drawSVG = function() {
 // adds/removes nodes from the visualization
 ////////////////////////////////////////////////////////////////////////////////
 Webweb.prototype.setVisibleNodes = function() {
-    var count = getObjetPropertyCount(webweb.displayedNetworkData().nodeIdMap);
+    var count = this.getNodeCount(webweb.displayedNetworkData());
 
     if (! count) {
         count = this.maxNodeCount;
@@ -644,7 +675,6 @@ Webweb.prototype.createLinks = function() {
     }
 
     // push all the links to the list: links
-    var weights = [];
     for (var i in networkData.edgeList) {
         var edge = networkData.edgeList[i];
         var source = nodeIdMap[edge[0]];
@@ -653,8 +683,6 @@ Webweb.prototype.createLinks = function() {
         // if there's no edge weight, default it to 1
         var weight = edge.length == 3 ? parseFloat(edge[2]) : 1;
 
-        weights.push(weight);
-
         if (source <= target) {
             linkMatrix[source][target] += weight;
         }
@@ -668,6 +696,7 @@ Webweb.prototype.createLinks = function() {
         this.nodes[target].strength += weight;
     }
 
+    var edgeWeights = [];
     this.links = [];
     for (var source in linkMatrix) {
         for (var target in linkMatrix[source]) {
@@ -678,6 +707,7 @@ Webweb.prototype.createLinks = function() {
                     linkMatrix[source][target],
                 ));
             }
+            edgeWeights.push(linkMatrix[source][target]);
         }
     }
 
@@ -692,8 +722,8 @@ Webweb.prototype.createLinks = function() {
         delete this.allMetadata.strength;
     }
 
-    this.scales.links.width.domain(d3.extent(weights));
-    this.scales.links.opacity.domain(d3.extent(weights));
+    this.scales.links.width.domain(d3.extent(edgeWeights));
+    this.scales.links.opacity.domain(d3.extent(edgeWeights));
 }
 ////////////////////////////////////////////////////////////////////////////////
 // Webweb:
@@ -1037,8 +1067,7 @@ function changeNetwork(networkName) {
     networkSelect.value = networkName;
 
     webweb.display.networkName = networkName;
-    webweb.display.networkLayer = 0;
-    displayNetwork();
+    changeLayer(0);
 }
 function changeSizes(sizeBy) {
     webweb.display.sizeBy = sizeBy;
@@ -1169,11 +1198,13 @@ function getBinaryValues(type) {
 }
 function toggleLinkWidthScaling(checked) {
     var range = checked ? [0.5, 4] : [1, 1];
+    webweb.display.scaleLinkWidth = checked;
     webweb.scales.links.width.range(range);
     webweb.canvas.redraw();
 }
 function toggleLinkOpacityScaling(checked) {
-    var range = checked ? [0.4, 0.9] : [1, 1];
+    var range = checked ? [0.3, 0.9] : [1, 1];
+    webweb.display.scaleLinkOpacity = checked;
     webweb.scales.links.opacity.range(range);
     webweb.canvas.redraw();
 }
@@ -1340,21 +1371,29 @@ Legend.prototype.drawLegendLabel = function(pushDown) {
     webweb.legendText.push(text);
 }
 Legend.prototype.drawLegendText = function(pushDown, pushRight) {
+    var valuesCount = this.values.length;
     this.text.forEach(function(d, i) {
-        var text = new Text(d, pushRight, pushDown(i) + 3.5, "12px");
-        webweb.legendText.push(text);
+        // only draw text for as many values as there are
+        if (i < valuesCount) {
+            var text = new Text(d, pushRight, pushDown(i) + 3.5, "12px");
+            webweb.legendText.push(text);
+        }
     });
 }
 Legend.prototype.drawLegendValues = function(pushDown, pushRight, sizeFunction, colorFunction) {
+    var textCount = this.text.length;
     this.values.forEach(function(d, i){
-        var node = new Node(-1);
-        node.fixedRadius = sizeFunction(d);
-        node.x = pushRight;
-        node.y = pushDown(i);
-        node.__scaledColor = colorFunction(i);
-        node.nonInteractive = true;
+        // only draw text for as many values as there are
+        if (i < textCount) {
+            var node = new Node(-1);
+            node.fixedRadius = sizeFunction(d);
+            node.x = pushRight;
+            node.y = pushDown(i);
+            node.__scaledColor = colorFunction(i);
+            node.nonInteractive = true;
 
-        webweb.legendNodes.push(node);
+            webweb.legendNodes.push(node);
+        }
     });
 }
 Legend.prototype.makeBinaryLegend = function() {
@@ -1490,12 +1529,14 @@ CanvasState.prototype.redraw = function() {
         text.draw(this.context);
     }, this);
 
-    this.webweb.legendNodes.forEach(function(node) {
-        node.draw(this.context);
-    }, this);
-    this.webweb.legendText.forEach(function(text) {
-        text.draw(this.context);
-    }, this);
+    if (this.webweb.display.showLegend) {
+        this.webweb.legendNodes.forEach(function(node) {
+            node.draw(this.context);
+        }, this);
+        this.webweb.legendText.forEach(function(text) {
+            text.draw(this.context);
+        }, this);
+    }
 }
 
 CanvasState.prototype.getMouseState = function(event) {
@@ -1972,13 +2013,16 @@ function saveIt(fileName, fileType, content) {
         alert("can't save :(");
     }
 }
-function writeSVGDownloadLink() {
+function getSVGHTML(){
     var svg = drawSVG();
     svg.setAttribute("title", webweb.display.networkName);
-    svg.setAttribute("version", 1.1)
-    svg.setAttribute("xmlns", "http://www.w3.org/2000/svg")
-
-    saveIt(webweb.display.networkName, "image/svg+xml", svg.outerHTML);
+    svg.setAttribute("version", 1.1);
+    svg.setAttribute("xmlns", "http://www.w3.org/2000/svg");
+    return svg.outerHTML;
+}
+function writeSVGDownloadLink() {
+    html = getSVGHTML();
+    saveIt(webweb.display.networkName, "image/svg+xml", html);
 };
 function drawSVG() {
     var svg = document.createElementNS("http://www.w3.org/2000/svg", "svg");
@@ -1994,12 +2038,14 @@ function drawSVG() {
         svg.appendChild(text.drawSVG());
     });
 
-    webweb.legendNodes.forEach(function(node) {
-        svg.appendChild(node.drawSVG());
-    });
-    webweb.legendText.forEach(function(text) {
-        svg.appendChild(text.drawSVG());
-    });
+    if (webweb.display.showLegend) {
+        webweb.legendNodes.forEach(function(node) {
+            svg.appendChild(node.drawSVG());
+        });
+        webweb.legendText.forEach(function(text) {
+            svg.appendChild(text.drawSVG());
+        });
+    }
 
     return svg;
 }
